Type: Package
Package: serocalculator
Title: Estimating Infection Rates from Serological Data
Version: 1.4.1
Authors@R: c(
    person("Kristina", "Lai", , "kwlai@ucdavis.edu", role = c("aut", "cre")),
    person("Chris", "Orwa", role = "aut"),
    person("Kwan Ho", "Lee", , "ksjlee@ucdavis.edu", role = "ctb"),
    person("Peter", "Teunis", , "p.teunis@emory.edu", role = c("aut", "cph"),
           comment = "Author of the method and original code."),
    person("Kristen", "Aiemjoy", , "kaiemjoy@ucdavis.edu", role = "aut"),
    person("Douglas Ezra", "Morrison", , "demorrison@ucdavis.edu", role = "aut")
  )
Description: Translates antibody levels measured in cross-sectional
    population samples into estimates of the frequency with which
    seroconversions (infections) occur in the sampled populations.
    Replaces the previous `seroincidence` package.
License: GPL-3
URL: https://ucd-serg.github.io/serocalculator/,
        https://github.com/UCD-SERG/serocalculator
BugReports: https://github.com/UCD-SERG/serocalculator/issues
Depends: R (>= 4.1.0)
Imports: cli, doParallel, dplyr, foreach, ggplot2, patchwork,
        lifecycle, magrittr, Rcpp, rlang, rngtools, scales, stats,
        tibble, tidyr, tidyselect, utils, purrr, and, glue, stringr,
        parallel, labelled
Suggests: bookdown, DT, fs, ggbeeswarm, knitr, mixtools, pak, quarto,
        rmarkdown, spelling, ssdtools (>= 1.0.6.9016), testthat (>=
        3.0.0), tidyverse, qrcode, vdiffr, withr, forcats, rex, readr
LinkingTo: Rcpp
Config/testthat/edition: 3
Config/Needs/roxygen2: roxygen2, moodymudskipper/devtag
Config/Needs/lint: r-lib/lintr
Config/Needs/website: quarto, lewinfox/foodwebr
Config/Needs/check: readr
Encoding: UTF-8
Language: en-US
LazyData: true
NeedsCompilation: yes
RoxygenNote: 7.3.3
Packaged: 2026-03-25 11:03:26 UTC; kwlai
Author: Kristina Lai [aut, cre],
  Chris Orwa [aut],
  Kwan Ho Lee [ctb],
  Peter Teunis [aut, cph] (Author of the method and original code.),
  Kristen Aiemjoy [aut],
  Douglas Ezra Morrison [aut]
Maintainer: Kristina Lai <kwlai@ucdavis.edu>
Repository: CRAN
Date/Publication: 2026-03-25 22:30:07 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 13:51:57 UTC; unix
Archs: serocalculator.so.dSYM
