# Generated by roxygen2: do not edit by hand

S3method("[",seroincidence.by)
S3method(autoplot,curve_params)
S3method(autoplot,pop_data)
S3method(autoplot,seroincidence)
S3method(autoplot,seroincidence.by)
S3method(autoplot,sim_results)
S3method(autoplot,summary.seroincidence.by)
S3method(compare_seroincidence,default)
S3method(compare_seroincidence,seroincidence)
S3method(compare_seroincidence,seroincidence.by)
S3method(print,seroincidence)
S3method(print,seroincidence.by)
S3method(print,summary.pop_data)
S3method(print,summary.seroincidence.by)
S3method(strata,default)
S3method(summary,pop_data)
S3method(summary,seroincidence)
S3method(summary,seroincidence.by)
export(analyze_sims)
export(as_curve_params)
export(as_noise_params)
export(as_pop_data)
export(as_sr_params)
export(autoplot)
export(check_pop_data)
export(compare_seroincidence)
export(count_strata)
export(est.incidence)
export(est.incidence.by)
export(est_seroincidence)
export(est_seroincidence_by)
export(expect_snapshot_data)
export(f_dev)
export(f_dev0)
export(fdev)
export(get_biomarker_levels)
export(get_biomarker_names)
export(get_biomarker_names_var)
export(get_values)
export(get_values_var)
export(graph.curve.params)
export(graph_loglik)
export(graph_seroresponse_model_1)
export(ids)
export(ids_varname)
export(llik)
export(load_curve_params)
export(load_noise_params)
export(load_pop_data)
export(load_sr_params)
export(log_likelihood)
export(serocalculator_example)
export(set_id_var)
export(sim.cs)
export(sim.cs.multi)
export(sim_pop_data)
export(sim_pop_data_multi)
export(strat_ests_barplot)
export(strat_ests_scatterplot)
export(strata)
importFrom(Rcpp,sourceCpp)
importFrom(doParallel,registerDoParallel)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,anti_join)
importFrom(dplyr,any_of)
importFrom(dplyr,bind_rows)
importFrom(dplyr,count)
importFrom(dplyr,distinct)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_all)
importFrom(dplyr,if_any)
importFrom(dplyr,if_else)
importFrom(dplyr,inner_join)
importFrom(dplyr,is.grouped_df)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,pull)
importFrom(dplyr,relocate)
importFrom(dplyr,rename)
importFrom(dplyr,row_number)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,semi_join)
importFrom(dplyr,slice_head)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(foreach,"%:%")
importFrom(foreach,"%dopar%")
importFrom(foreach,foreach)
importFrom(ggplot2,aes)
importFrom(ggplot2,autoplot)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,vars)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(rngtools,RNGseq)
importFrom(rngtools,setRNG)
importFrom(stats,dlnorm)
importFrom(stats,formula)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,nlm)
importFrom(stats,optim)
importFrom(stats,pgamma)
importFrom(stats,plnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,runif)
importFrom(stats,xtabs)
importFrom(tibble,as_tibble)
importFrom(tibble,column_to_rownames)
importFrom(tibble,tibble)
importFrom(tidyr,drop_na)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,pivot_wider)
importFrom(tidyselect,contains)
importFrom(tidyselect,ends_with)
importFrom(utils,capture.output)
importFrom(utils,download.file)
importFrom(utils,head)
importFrom(utils,tail)
importFrom(utils,unzip)
useDynLib(serocalculator, .registration = TRUE)
